@@ -1,11 +1,12 @@
 package Sort::Key::Multi;
 
-our $VERSION = '1.23';
+our $VERSION = '1.30';
 
 use warnings;
 use strict;
 
 use Sort::Key qw(multikeysorter multikeysorter_inplace);
+use Sort::Key::Types;
 
 use Carp;
 our @CARP_NOT = qw(Sort::Key);
@@ -17,12 +18,14 @@ my %type = qw( i integer
 	       s string
 	       l locale);
 
+my $one_char_types = join('', keys %Sort::Key::Types::mktypes);
+
 sub import {
     shift;
     for my $name (@_) {
 	my $sub = $sub{$name};
 	unless (defined $sub) {
-	    my ($types, $inplace) = $name =~ /^((?:r?[snil]\d*_*)+)keysort((?:_?inplace)?)$/
+	    my ($types, $inplace) = $name =~ /^((?:r?[$one_char_types]\d*_*)+)keysort((?:_?inplace)?)$/o
 		or croak "invalid name for multikey sorter '$name'";
 	    my @types;
 	    while ($types =~ /(r?)(.)(\d*)_*/g) {
